//=============================================================================
// Copyright  Micromega Corporation 2005-2009. All rights reserved.
//
// @file	graph.c
// @target	CSS PIC C compiler
//
// This program demonstrates the use of the uM-FPU V3.1 floating point
// chip with the CSS PIC C compiler using an SPI or I2C interface. It draws a
// simple graph of the sine and cosine functions in the terminal window.
//
// @author	Cam Thompson, Micromega Corporation
// @version
//	February 6, 2009
//	- added I2C support
//	May 7, 2008
//	- updated for CSS PIC C compiler
//	February 1, 2008
//	- fixed second graph to be cosine
//	September 20, 2007
//	- original version
//=============================================================================

// these settings must be changed depending on the PIC processor used
#include <16F877.h>
#device ICD=true
#fuses XT,NOWDT,NOPUT,NOPROTECT,NOBROWNOUT,NOLVP,NOCPD
#use delay(clock=20000000)
#use rs232(baud=19200, xmit=PIN_C6, rcv=PIN_C7)

#include <fpu.h>
//#include <fpu_spi.c>				// include for SPI interface
#include <fpu_i2c.c>				// include for I2C interface

//-------------------- uM-FPU register definitions ----------------------------

#define Angle		1				// angle
#define Point		2				// point on graph

//------------------ local prototypes -----------------------------------------

void graph(void);

//------------------ main -----------------------------------------------------

void main(void) {
	int i;

	printf("\r\nGraph demo\r\n");	// program name

	// reset the uM-FPU and print version
	if (fpu_reset() == SYNC_CHAR) {
		print_version();
		print_CRLF();
	}
	else {
		printf("uM-FPU not detected");
		return;
	}

	// graph sine from 0 to 360 degrees (2*PI radians)
	printf("\r\nGraph of sine\r\n");
	printf("-1        0         1\r\n");
	printf("---------------------\r\n");
    for (i = 0; i <= 20; i++) {
		fpu_write4(SELECTA, Angle, LOADPI, FSET0);
		fpu_write4(FMULI, 2*i, FDIVI, 20);
		fpu_write(SIN);
		graph();
	}

    // graph cosine from 0 to 360 degrees (2*PI radians)
	printf("\r\nGraph of cosine\r\n");
	printf("-1        0         1\r\n");
	printf("---------------------\r\n");
    for (i = 0; i <= 20; i++) {
		fpu_write4(SELECTA, Angle, LOADPI, FSET0);
		fpu_write4(FMULI, 2*i, FDIVI, 20);
		fpu_write(COS);
		graph();
	}

	printf("\r\nDone.\r\n");
}

//-------------------- graph --------------------------------------------------

void graph(void) {
	signed int i;
	char p, ch;

    // calculate point on graph for value
	fpu_write4(SELECTA, Point, FSET, Angle);
	fpu_write3(FMULI, 10, FIXR);
	fpu_wait();
	fpu_write(LREADBYTE);
	fpu_readDelay();
    p = fpu_read();

    // plot the point on the graph
	for (i = -10; i <= 10; i++) {
		if (i == p) ch = '*';
		else if (i == 0) ch = '|';
		else ch = ' ';
		putchar(ch);
	}

    // display the angle value
	putchar(' ');
	fpu_write2(SELECTA, Angle);
	print_float(85);
	print_CRLF();
}
