//=============================================================================
// Copyright  Micromega Corporation 2005-2009. All rights reserved.
//
// @file	sample.c
// @target	CSS PIC C compiler
//
// Simple example of using the uM-FPU V3.1 support files.
//
// @author	Cam Thompson, Micromega Corporation
// @version
//	February 6, 2009
//	- added I2C support
//	May 7, 2008
//	- updated for CSS PIC C compiler
//	August 31, 2007
//	- updated for uM-FPU V3.1
//	November 17, 2006
//	- original version
//=============================================================================

// these settings must be changed depending on the PIC processor used
#include <16F877.h>
#device ICD=true
#fuses XT,NOWDT,NOPUT,NOPROTECT,NOBROWNOUT,NOLVP,NOCPD
#use delay(clock=20000000)
#use rs232(baud=19200, xmit=PIN_C6, rcv=PIN_C7)

#include <fpu.h>
//#include <fpu_spi.c>				// include for SPI interface
#include <fpu_i2c.c>				// include for I2C interface

//-------------------- uM-FPU register definitions ----------------------------

#define DiameterIn		1				// diameter in inches
#define Circumference	2				// circumference
#define Area			3				// area
#define Pi				4				// constant pi

//------------------ main -----------------------------------------------------

int main(void) {
	int diameterCm;

	// print program name
	printf("\r\nConversion Example\r\n------------------\r\n");

	//------------------------------------
	// Reset the uM-FPU and print version.
	//------------------------------------
	if (fpu_reset() == SYNC_CHAR) {
		print_version();
		print_CRLF();
	}
	else {
		printf("uM-FPU not detected");
		return;
	}

	//-----------------------------
	// Load constant for later use.
	//-----------------------------
	fpu_write4(SELECTA, Pi, LOADPI, FSET0);

	//---------------------------------------------------------------------------
	// Get diameter in centimeters.  The value would typically come from a sensor
	// reading, but in this example an assumed value of 25 is used.
	//---------------------------------------------------------------------------
	diameterCm = 25;
	printf("Diameter (cm):       %i\r\n", diameterCm);

	//------------------------------
	// convert inches to centimeters
	//------------------------------
	fpu_write4(SELECTA, DiameterIn, FSETI, diameterCm);
	fpu_write2(FCNV, 5);
	printf("Diameter (in.):      ");
	print_float(0);
	print_CRLF();

	//------------------------------
	// circumference = diameter * pi
	//------------------------------
	fpu_write4(SELECTA, Circumference, FSET, DiameterIn);
	fpu_write2(FMUL, Pi);
	printf("Circumference (in.): ");
	print_float(0);
	print_CRLF();

	//----------------------------
	// area = (diameter / 2)^2 * pi
 	//----------------------------
	fpu_write4(SELECTA, Area, FSET, DiameterIn);
	fpu_write2(FDIVI, 2);
	fpu_write4(FMUL, Area, FMUL, Pi);
	printf("Area (sq.in.):       ");
	print_float(0);
	print_CRLF();

	printf("\r\nDone.\r\n");
}
