//=============================================================================
// Copyright  Micromega Corporation 2005-2009. All rights reserved.
//
// @file	template.c
// @target	CSS PIC C compiler
//
// This program provides an example of using the uM-FPU V3.1 floating point
// coprocessor with the CSS PIC C compiler using an SPI or I2C interface. It
// shows the initial FPU reset sequence and prints the version number of the
// FPU chip.
//
// @author	Cam Thompson, Micromega Corporation
// @version
//	February 6, 2009
//	- added I2C support
//	May 6, 2008
//	- original version
//=============================================================================

// Note: these settings must be changed depending on the PIC processor used
#include <16F877.h>
#device ICD=true
#fuses XT,NOWDT,NOPUT,NOPROTECT,NOBROWNOUT,NOLVP,NOCPD
#use delay(clock=20000000)
#use rs232(baud=19200, xmit=PIN_C6, rcv=PIN_C7)

#include <fpu.h>
//#include <fpu_spi.c>				// include for SPI interface
#include <fpu_i2c.c>				// include for I2C interface

//------------------ main -----------------------------------------------------

void main() {

	// print program name
	printf("\r\nTemplate\r\n");

	// Reset the uM-FPU and print version
	if (fpu_reset() == SYNC_CHAR) {
		print_version();
		print_CRLF();
	}
	else {
		printf("uM-FPU not detected");
		return;
	}

//	Insert main application code here.
//	FPU instructions are sent using fpu_write routines.
//	e.g.
//		fpu_write4(SELECTA, 1, LOADPI, FSET0);

	printf("\r\nDone.\r\n");
}
